# Posteriors

::: sbi.inference.posteriors.direct_posterior.DirectPosterior
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.posteriors.importance_posterior.ImportanceSamplingPosterior
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.posteriors.mcmc_posterior.MCMCPosterior
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.posteriors.rejection_posterior.RejectionPosterior
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.posteriors.score_posterior.ScorePosterior
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.posteriors.vi_posterior.VIPosterior
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true
